/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.data;

import java.util.Objects;


/**
 * Represents a single element. Note that this class would most likely need
 * quite a few optimizations for larger data sets!
 */
public class DataElement {

	private String[] attributes;


	public DataElement(String[] attributes) {
		Objects.requireNonNull(attributes);

		for (String attribute : attributes) {
			Objects.requireNonNull(attribute);
		}

		this.attributes = attributes;
	}


	/**
	 * @param attribute The attribute to retrieve.
	 * @return The attribute value as a string.
	 */
	public String getString(int attribute) {
		return attributes[attribute];
	}


	/**
	 * @param attribute The attribute to retrieve.
	 * @return The attribute value as a double.
	 */
	public double getDouble(int attribute) {
		return Double.parseDouble(attributes[attribute]);
	}


	/**
	 * @param attribute The attribute to retrieve.
	 * @return The attribute value as an int.
	 */
	public int getInt(int attribute) {
		return Integer.parseInt(attributes[attribute]);
	}


	/**
	 * @return The number of attributes in the row.
	 */
	protected int getAttributeCount() {
		return attributes.length;
	}
}
