/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.gui;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;

import vispaca.data.DataManager;
import vispaca.misc.ScatterConfig;
import vispaca.misc.PanelUtil;


/**
 * Contains all config panels for the scatter panel.
 */
public class VScatterConfigDialog extends JDialog {

	private static final long serialVersionUID = 3972577441701603583L;

	private GridBagConstraints constraints = PanelUtil.getVerticalConstraints();
	private JPanel wrapperPanel = new JPanel();


	public VScatterConfigDialog(Frame frame, DataManager dataManager, ScatterConfig config) {
		super(frame);

		setLayout(new BorderLayout());
		setModal(true);
		setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);

		wrapperPanel.setLayout(new GridBagLayout());

		wrapperPanel.add(new VNumberConfigPanel(dataManager, config.getX(), "X"), constraints);
		wrapperPanel.add(new VNumberConfigPanel(dataManager, config.getY(), "Y"), constraints);
		wrapperPanel.add(new VNumberConfigPanel(dataManager, config.getColor(), "Color"), constraints);

		JButton closeButton = new JButton("Close");
		closeButton.addActionListener(new CloseButtonListener());

		add(wrapperPanel, BorderLayout.CENTER);
		add(closeButton, BorderLayout.SOUTH);

		setTitle("VisPaca - Scatter - Config");
		setSize(480, 320);
		setLocationRelativeTo(frame);
	}


	/**
	 * Closes the dialog when the close button is clicked.
	 */
	public class CloseButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			dispose();
		}
	}
}
