/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.misc;

import java.io.PrintStream;
import java.util.Objects;


/**
 * A simple logger.
 */
public class Log {

	public final static boolean PRINT_ERR = true;
	public final static boolean PRINT_WRN = true;
	public final static boolean PRINT_INF = true;

	private static PrintStream stream = System.err;


	public static void err(String message) {
		if (PRINT_ERR) {
			stream.println("ERR [" + getCallerName() + "] " + message);
		}
	}


	public static void wrn(String message) {
		if (PRINT_WRN) {
			stream.println("WRN [" + getCallerName() + "] " + message);
		}
	}


	public static void inf(String message) {
		if (PRINT_INF) {
			stream.println("INF [" + getCallerName() + "] " + message);
		}
	}


	public static void setStream(PrintStream stream) {
		Objects.requireNonNull(stream);
		Log.stream = stream;
	}


	public static PrintStream getStream() {
		return stream;
	}


	private static String getCallerName() {
		try {
			StackTraceElement ste = new Throwable().getStackTrace()[2];
			String classSplit[] = ste.getClassName().split("\\.");
			String className = classSplit[classSplit.length - 1];
			String methodName = ste.getMethodName();
			return className + '.' + methodName;
		} catch (Throwable t) {
			return "?";
		}
	}
}
