/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.misc;

import java.util.Objects;

import vispaca.data.DataTable;


/**
 * Handles the parallel coordinate system configuration.
 */
public class ParallelConfig {

	private AttributeConfig[] axises = new AttributeConfig[0];
	private AttributeConfig color = new AttributeConfig();


	public ParallelConfig() {

	}


	public ParallelConfig(DataTable dataTable, int... attributes) {
		init(dataTable, attributes);
	}


	/**
	 * Sets attribute defaults.
	 */
	public void init(DataTable dataTable, int... attributes) {
		Objects.requireNonNull(attributes);

		axises = new AttributeConfig[attributes.length];

		for (int i = 0; i < attributes.length; i++) {
			axises[i] = new AttributeConfig(dataTable, attributes[i]);
		}
	}


	/**
	 * @return The attribute config for an axis.
	 */
	public AttributeConfig getAxis(int axis) {
		return axises[axis];
	}


	/**
	 * @return The number of axises.
	 */
	public int getAxisCount() {
		return axises.length;
	}


	/**
	 * @return The color attribute config.
	 */
	public AttributeConfig getColor() {
		return color;
	}
}
